#!/usr/bin/env python3

import sys
from PyQt5.QtCore import QUrl, QCoreApplication, QByteArray
from PyQt5.QtNetwork import (
    QNetworkAccessManager,
    QNetworkRequest,
    QNetworkReply,
    QHttpPart,
    QHttpMultiPart,
)


class Example:
    def __init__(self):
        self.network_manager = QNetworkAccessManager()
        self.multipart_post()

    def multipart_post(self):
        URL = "http://httpbin.org/post"
        body = QHttpMultiPart(QHttpMultiPart.ContentType.FormDataType)
        boundary = body.boundary()
        part = QHttpPart()
        part.setHeader(
            QNetworkRequest.KnownHeaders.ContentTypeHeader, "application/json"
        )
        part.setHeader(
            QNetworkRequest.KnownHeaders.ContentDispositionHeader,
            'form-data; name="test"',
        )
        data = QByteArray()
        data.append(b"test")
        part.setBody(data)
        body.append(part)
        request = QNetworkRequest(QUrl(URL))
        request.setHeader(QNetworkRequest.KnownHeaders.ContentTypeHeader, f'multipart/form-data; boundary={str(boundary, "utf-8")}')
        self.network_manager.finished.connect(self.handle_reply)
        response = self.network_manager.post(request, body)
        print(response)

    def handle_reply(self, reply):
        print(reply.error())
        print(reply.readAll())
        QCoreApplication.quit()


def main():
    app = QCoreApplication([])
    ex = Example()
    sys.exit(app.exec())


if __name__ == "__main__":
    main()
